@@ -6,7 +6,7 @@ import pyblish.backend.config
 HOST = 'python'
 FAMILY = 'test.family'
 
-registered = pyblish.backend.plugin.registered_paths
+registered = pyblish.backend.plugin.registered_paths()
 package_path = pyblish.backend.lib.main_package_path()
 plugin_path = os.path.join(package_path, 'backend', 'tests', 'plugins')
 pyblish.backend.plugin.deregister_all()
